@@ -8,6 +8,6 @@ class Connect:
     def __init__(self, bot_token: str, pgData: PostgresAuthData, message_logging: bool = False):
         self.data_base    = DataBase(pgData)
         self.tables       = Tables(self.data_base)
-        self.rooms        = Rooms(self.tables)
+        self.rooms        = Rooms(self.tables, self.data_base)
         self.telegram_bot = TelegramBot(bot_token, self.tables, self.rooms, message_logging)
 
